[telepathy-glib/master] account-manager: renamed _get_global_presence to _get_most_available_presence

Jonny Lamb jonny.lamb at collabora.co.uk
Tue Sep 22 03:45:39 PDT 2009


Signed-off-by: Jonny Lamb <jonny.lamb at collabora.co.uk>
---
 docs/reference/telepathy-glib-sections.txt |    2 +-
 telepathy-glib/account-manager.c           |   10 +++++-----
 telepathy-glib/account-manager.h           |    2 +-
 3 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/docs/reference/telepathy-glib-sections.txt b/docs/reference/telepathy-glib-sections.txt
index 9cdc7b0..ec0dbe2 100644
--- a/docs/reference/telepathy-glib-sections.txt
+++ b/docs/reference/telepathy-glib-sections.txt
@@ -3079,7 +3079,7 @@ tp_account_manager_create_account_async
 tp_account_manager_create_account_finish
 tp_account_manager_ensure_account
 tp_account_manager_get_accounts
-tp_account_manager_get_global_presence
+tp_account_manager_get_most_available_presence
 tp_account_manager_set_all_requested_presences
 <SUBSECTION>
 TP_ACCOUNT_MANAGER_FEATURE_CORE
diff --git a/telepathy-glib/account-manager.h b/telepathy-glib/account-manager.h
index e464444..0b766dc 100644
--- a/telepathy-glib/account-manager.h
+++ b/telepathy-glib/account-manager.h
@@ -83,7 +83,7 @@ GList *tp_account_manager_get_accounts (TpAccountManager *manager);
 void tp_account_manager_set_all_requested_presences (TpAccountManager *manager,
     TpConnectionPresenceType type, const gchar *status, const gchar *message);
 
-TpConnectionPresenceType tp_account_manager_get_global_presence (
+TpConnectionPresenceType tp_account_manager_get_most_available_presence (
     TpAccountManager *manager, gchar **status, gchar **message);
 
 void tp_account_manager_create_account_async (TpAccountManager *manager,
diff --git a/telepathy-glib/account-manager.c b/telepathy-glib/account-manager.c
index f5ce2fd..ef4128a 100644
--- a/telepathy-glib/account-manager.c
+++ b/telepathy-glib/account-manager.c
@@ -1051,8 +1051,8 @@ tp_account_manager_get_accounts (TpAccountManager *manager)
  * (@type, @status and @message). Note that the presence requested here is
  * merely a request, and if might not be satisfiable.
  *
  * You can find the actual global presence across all accounts by calling
  * tp_account_manager_get_global_presence().
  *
  * Since: 0.7.UNRELEASED
  */
@@ -1097,20 +1097,20 @@ tp_account_manager_set_all_requested_presences (TpAccountManager *manager,
 }
 
 /**
- * tp_account_manager_get_global_presence:
+ * tp_account_manager_get_most_available_presence:
  * @manager: a #TpAccountManager
  * @status: a string to fill with the actual status
  * @message: a string to fill with the actual status message
  *
  * <!-- -->
  *
- * Returns: the actual global presence
+ * Returns: the most available presence across all accounts
  *
  * Since: 0.7.UNRELEASED
  */
 
 TpConnectionPresenceType
-tp_account_manager_get_global_presence (TpAccountManager *manager,
+tp_account_manager_get_most_available_presence (TpAccountManager *manager,
     gchar **status,
     gchar **message)
 {
@@ -1051,8 +1051,8 @@ tp_account_manager_get_accounts (TpAccountManager *manager)
  * merely a request, and if might not be satisfiable.
  *
- * You can find the actual global presence across all accounts by calling
- * tp_account_manager_get_global_presence().
+ * You can find the most available presence across all accounts by calling
+ * tp_account_manager_get_most_available_presence().
  *
  * Since: 0.7.UNRELEASED
-- 
1.5.6.5




More information about the telepathy-commits mailing list